@@ -79,8 +79,23 @@ def list_fields(name_or_definition):
 	return definition.list_fields()
 
 
-def validate_input(definition_or_name, value, field_fqn=None, field_name=None, dependent_values={}):
-	results = Definitions.Index.validate_input(None, field_fqn, field_name, definition_or_name, value, dependent_values)
+def validate_input(
+			definition_or_name,
+			value,
+			field_fqn=None,
+			field_name=None,
+			dependent_values={},
+			**rules_kw
+		):
+	results = Definitions.Index.validate_input(
+			None,
+			field_fqn,
+			field_name,
+			definition_or_name,
+			value,
+			dependent_values,
+			**rules_kw
+		)
 	return results
 
 
