@@ -6,7 +6,7 @@ def initialize():
 	from cro_validate.classes.configuration_classes import Config
 
 	Config.exception_factory = Exceptions.DefaultExceptionFactory()
-	Config.example_generator_factory = Examples.DefaultGeneratorFactory()
+	Config.example_generator_factory = Examples.DefaultExampleGeneratorFactory()
 	Config.default_examples_provider = Examples.DefaultExamplesProvider()
 	Config.definition_name_resolver = NameResolvers.DefaultNameResolver()
 	Config.parameter_name_resolver = NameResolvers.DefaultNameResolver()
