@@ -234,7 +234,8 @@ class Definition:
 				input_names=input_names,
 				output_names=output_names,
 				dependencies=dependencies,
-				default_values=default_values)
+				default_values=default_values
+			)
 		return validator
 
 	def _get_obj_validator(self):
@@ -246,7 +247,11 @@ class Definition:
 		return validator
 
 	def _validate_array(self, results, field_fqn, field_name, definition, values, dependent_values):
-		if not isinstance(values, list):
+		if isinstance(values, list):
+			pass
+		elif isinstance(values, set):
+			values = [v for v in values]
+		else:
 			raise Config.exception_factory.create_input_error(field_fqn, 'Expected array, received: {0}'.format(type(values)))
 		items = []
 		i = 0
@@ -259,7 +264,16 @@ class Definition:
 	def _assign_value(self, results, field_fqn, field_name, definition, value, dependent_values):
 		results[field_name] = value
 
-	def validate(self, results, field_fqn, field_name, definition, value, dependent_values):
+	def validate(
+				self,
+				results,
+				field_fqn,
+				field_name,
+				definition,
+				value,
+				dependent_values,
+				**rules_kw
+			):
 		'''
 		The validate func
 		'''
@@ -282,7 +296,7 @@ class Definition:
 					results[field_name] = None
 					return
 				else:
-					raise Config.exception_factory.create_input_error(field_name, 'Not nullable.')
+					raise Config.exception_factory.create_input_error(field_fqn, 'Not nullable.')
 			if dependent_definition_name is not None:
 				Index.validate_input(
 						results,
@@ -295,7 +309,7 @@ class Definition:
 			else:
 				self.validator(results, field_fqn, field_name, self, value, dependent_values)
 			for rule in self.rules:
-				results[field_name] = rule.execute(field_fqn, results[field_name])
+				results[field_name] = rule.execute(field_fqn, results[field_name], **rules_kw)
 			return results
 		except Exception as ex:
 			if self.internal:
@@ -595,10 +609,18 @@ class Index:
 			Index._idx[entry] = definition
 		return definition
 
-	def validate_input(validated, field_fqn, field_name, definition_or_name, value, dependent_values={}):
+	def validate_input(
+				validated,
+				field_fqn,
+				field_name,
+				definition_or_name,
+				value,
+				dependent_values={},
+				**rules_kw
+			):
 		definition = Index.get(definition_or_name)
 		results = Parameters.Index.ensure(validated)
-		definition.validate(results, field_fqn, field_name, definition, value, dependent_values)
+		definition.validate(results, field_fqn, field_name, definition, value, dependent_values, **rules_kw)
 		return results
 
 	def ensure_alias(name, alias):
