@@ -90,7 +90,8 @@ class Field:
 				ignored=Utils.Empty,
 				unvalidated=Utils.Empty,
 				dependencies=Utils.Empty,
-				default_value=Utils.Empty):
+				default_value=Utils.Empty
+			):
 		def _set_member(name, value):
 			if Utils.Empty.isempty(value):
 				return
@@ -341,7 +342,7 @@ class ModelValidator:
 			display_names = []
 			for entry in missing:
 				display_names.append(self.get_field_input_display_name(entry))
-			raise Config.exception_factory.create_input_error(self.name, 'Missing required values: {0}'.format(', '.join(display_names)))
+			raise Config.exception_factory.create_input_error(fqn, 'Missing required values: {0}'.format(', '.join(display_names)))
 		for entry in self.dependency_order:
 			# Unvalidated
 			#############
@@ -353,7 +354,7 @@ class ModelValidator:
 			field_definition_name = self.get_field_definition_name(entry)
 			field_definition = Definitions.Index.get(field_definition_name)
 			if entry not in kw:
-				if field_definition.has_default_value():
+				if field_definition.has_default_value() and entry in self.required:
 					result[entry] = field_definition.get_default_value(entry)
 				continue
 			# Normal Field
